@@ -198,31 +198,6 @@ def force_add_random_vertex_on_low_used_color(C):
 
 	return C
 
-def parallel_force_add_random_vertex_on_low_used_color(C):
-	C = C.copy()
-	colored_vertices = np.any( C,axis=0 )
-
-	if np.any(~colored_vertices):
-		vertices_per_color = np.sum(C,axis=1)
-		proposal_weights = np.max(vertices_per_color) - vertices_per_color + 0.2
-		skewed_proposal_weights = (proposal_weights / np.max(proposal_weights))**5
-		weights = skewed_proposal_weights / np.sum(skewed_proposal_weights)
-
-		color = np.random.choice( np.arange(C.shape[0]), p=weights )
-
-		uncolored_vertices = np.nonzero(~colored_vertices)[0]
-
-		color_proposals = ~edges_matrix[ uncolored_vertices ] & C[color]
-		where_max = np.nonzero( np.sum( color_proposals ,axis=1) == np.max(np.sum( color_proposals ,axis=1)) )[0]
-		some_max = np.random.choice(where_max)
-
-		C[color] = ~edges_matrix[ uncolored_vertices[some_max] ] & C[color]
-		C[color][uncolored_vertices[some_max]] = True
-		
-		return check_average_and_add_row(C)
-
-	return C
-
 def parallel_add_random_vertex(C):
 	"""
 		Stikk need to check average
