@@ -28,41 +28,10 @@ import frigidum
 
 import numpy as np
 
+from frigidum.examples import pcb442
 
-FRIGIDUM_PATH = os.path.dirname( frigidum.__file__ )
-DATA_PATH = FRIGIDUM_PATH + '/data_files/'
-
-"""
-	REGEX taken from https://www.regular-expressions.info/floatingpoint.html
-
-	Needed to parse the .tsp format from tsplib
-"""
-re_node_line = re.compile("(\d+) ([0-9]*\.?[0-9]+)([eE][-+]?[0-9]+)? ([0-9]*\.?[0-9]+)([eE][-+]?[0-9]+)?")
-nodes_dict = {}
-pcb442_path = DATA_PATH + 'pcb442.tsp'
-
-"""
-
-	Parse the .tsp file in TSPLIB format
-
-"""
-
-with open(pcb442_path) as f:
-	for line in f:
-		result = re_node_line.match(line)
-		if result:
-			node_id = int(result.group(1))
-			
-			x_coord = float(result.group(2) + result.group(3))
-			y_coord = float(result.group(4) + result.group(5))
-
-			nodes_dict[ node_id ] = (x_coord, y_coord)
-
-nodes_count = max(nodes_dict.keys())
-nodes = np.zeros( (nodes_count,2) )
-
-for k in nodes_dict:
-	nodes[k-1] = np.array( nodes_dict[k] )
+nodes_count = pcb442.nodes_count
+nodes = pcb442.pcb442_nodes
 
 """
 	Calculate the distance matrix
@@ -486,7 +455,7 @@ def stochastic_reroute_missing( incomplete_route, missing_vertices ):
 		transformed_weights = uw_max - dist_reroute + (uw_min/100)
 		transformed_weights = transformed_weights / np.max(transformed_weights)
 
-		stretched_weights = transformed_weights ** 75
+		stretched_weights = transformed_weights ** 25
 
 
 		weights = stretched_weights / np.sum(stretched_weights)
